<?php

if ( ! function_exists( 'solvent_core_add_team_interactive_columns_shortcode' ) ) {
	/**
	 * Function that isadding shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes - Array of registered shortcodes
	 *
	 * @return array
	 */
	function solvent_core_add_team_interactive_columns_shortcode( $shortcodes ) {
		$shortcodes[] = 'SolventCore_Team_Interactive_Columns_Shortcode';

		return $shortcodes;
	}

	add_filter( 'solvent_core_filter_register_shortcodes', 'solvent_core_add_team_interactive_columns_shortcode' );
}

if ( class_exists( 'SolventCore_List_Shortcode' ) ) {
	class SolventCore_Team_Interactive_Columns_Shortcode extends SolventCore_List_Shortcode {

		public function __construct() {
			$this->set_post_type( 'team' );
			$this->set_post_type_taxonomy( 'team-category' );
			$this->set_layouts( apply_filters( 'solvent_core_filter_team_interactive_columns_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'solvent_core_filter_team_interactive_columns_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( SOLVENT_CORE_CPT_URL_PATH . '/team/shortcodes/team-interactive-columns' );
			$this->set_base( 'solvent_core_team_interactive_columns' );
			$this->set_name( esc_html__( 'Team Interactive Columns', 'solvent-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays list of teams', 'solvent-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'solvent-core' ),
				)
			);
			$this->map_list_options(
				array(
					'exclude_behavior' => array( 'masonry', 'justified-gallery', 'slider' ),
					'exclude_columns'  => array( '1', '2', '3', '6' ),
				)
			);
			$this->map_query_options( array( 'post_type' => $this->get_post_type() ) );
			$this->map_layout_options( array( 'layouts' => $this->get_layouts() ) );
			$this->map_extra_options();
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'solvent_core_team_interactive_columns', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );

			$atts = $this->get_atts();

			$atts['post_type']       = $this->get_post_type();
			$atts['taxonomy_filter'] = $this->get_post_type_filter_taxonomy( $atts );

			// Additional query args
			$atts['additional_query_args'] = $this->get_additional_query_args( $atts );

			$atts['holder_classes']          = $this->get_holder_classes( $atts );
			$atts['holder_styles']           = $this->get_holder_styles( $atts );
			$atts['item_classes']            = $this->get_item_classes( $atts );
			$atts['query_result']            = new WP_Query( solvent_core_get_query_params( $atts ) );
			$atts['number_of_items_numeric'] = $atts['columns'];
			$atts['slider_attr']             = $this->get_slider_data( $atts );
			$atts['has_single']              = solvent_core_team_has_single();
			$atts['data_attr']               = solvent_core_get_pagination_data( SOLVENT_CORE_REL_PATH, 'post-types/team/shortcodes', 'team-interactive-columns', 'team', $atts );

			$atts['this_shortcode'] = $this;

			return solvent_core_get_template_part( 'post-types/team/shortcodes/team-interactive-columns', 'templates/content', $atts['behavior'], $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-team-interactive-columns';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-item-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['columns'] ) ? ' qodef-ic-' . $atts['columns'] : ' qodef-ic-5';

			$list_classes   = $this->get_list_classes( $atts );
			$holder_classes = array_merge( $holder_classes, $list_classes );

			return implode( ' ', $holder_classes );
		}

		private function get_holder_styles( $atts ) {
			$holder_styles = array();

			$list_styles   = $this->get_list_styles( $atts );
			$holder_styles = array_merge( $holder_styles, $list_styles );

			return $holder_styles;
		}

		private function get_item_classes( $atts ) {
			$item_classes = $this->init_item_classes();

			$item_classes[] = 'qodef-ic-item';

			$list_item_classes = $this->get_list_item_classes( $atts );

			$item_classes = array_merge( $item_classes, $list_item_classes );

			return implode( ' ', $item_classes );
		}

		public function get_title_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['text_transform'] ) ) {
				$styles[] = 'text-transform: ' . $atts['text_transform'];
			}

			return $styles;
		}
	}
}
