<?php

if ( ! function_exists( 'solvent_core_add_pricing_calculator_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function solvent_core_add_pricing_calculator_shortcode( $shortcodes ) {
		$shortcodes[] = 'SolventCore_Pricing_Calculator_Shortcode';

		return $shortcodes;
	}

	add_filter( 'solvent_core_filter_register_shortcodes', 'solvent_core_add_pricing_calculator_shortcode' );
}

if ( class_exists( 'SolventCore_Shortcode' ) ) {
	class SolventCore_Pricing_Calculator_Shortcode extends SolventCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'solvent_core_filter_pricing_calculator_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'solvent_core_filter_pricing_calculator_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( SOLVENT_CORE_SHORTCODES_URL_PATH . '/pricing-calculator' );
			$this->set_base( 'solvent_core_pricing_calculator' );
			$this->set_name( esc_html__( 'Pricing Calculator', 'solvent-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds pricing calculator element', 'solvent-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'solvent-core' ),
				)
			);

			$options_map = solvent_core_get_variations_options_map( $this->get_layouts() );

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'solvent-core' ),
					'options'       => $this->get_layouts(),
					'default_value' => 'standard',
					'visibility'    => array( 'map_for_page_builder' => $options_map['visibility'] ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'skin',
					'title'      => esc_html__( 'Skin', 'solvent-core' ),
					'options'    => solvent_core_get_select_type_options_pool( 'shortcode_skin' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'image',
					'name'       => 'image',
					'title'      => esc_html__( 'Image', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'image_size',
					'title'       => esc_html__( 'Image Size', 'solvent-core' ),
					'description' => esc_html__( 'For predefined image sizes input thumbnail, medium, large or full. If you wish to set a custom image size, type in the desired image dimensions in pixels (e.g. 400x400).', 'solvent-core' ),
					'dependency'  => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'title',
					'title'         => esc_html__( 'Title', 'solvent-core' ),
					'default_value' => esc_html__( 'Title', 'solvent-core' ),
					'dependency'    => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'price',
					'title'         => esc_html__( 'Initial Price', 'solvent-core' ),
					'default_value' => esc_html__( '2500', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'currency',
					'title'         => esc_html__( 'Currency', 'solvent-core' ),
					'default_value' => esc_html__( '$', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'period',
					'title'         => esc_html__( 'Period', 'solvent-core' ),
					'default_value' => esc_html__( 'Annually', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'repeater',
					'name'       => 'children',
					'title'      => esc_html__( 'Child Elements', 'solvent-core' ),
					'items'      => array(
						array(
							'field_type'    => 'text',
							'name'          => 'item_price',
							'title'         => esc_html__( 'Price', 'solvent-core' ),
							'default_value' => esc_html__( '500', 'qi-addons-for-elementor-premium' ),
						),
						array(
							'field_type'    => 'text',
							'name'          => 'item_title',
							'title'         => esc_html__( ' Title', 'solvent-core' ),
							'default_value' => '',
						),
						array(
							'field_type'    => 'select',
							'name'          => 'item_active',
							'title'         => esc_html__( 'Item Active', 'solvent-core' ),
							'options'       => solvent_core_get_select_type_options_pool( 'no_yes', false ),
							'default_value' => 'no',
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'textarea',
					'name'       => 'description',
					'title'      => esc_html__( 'Description', 'solvent-core' ),
				)
			);
			$this->import_shortcode_options(
				array(
					'shortcode_base'    => 'solvent_core_button',
					'exclude'           => array( 'custom_class' ),
					'additional_params' => array(
						'nested_group' => esc_html__( 'Button', 'solvent-core' ),
					),
				)
			);
			$this->map_extra_options();
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['image_params']   = $this->generate_image_params( $atts );
			$atts['button_params']  = $this->generate_button_params( $atts );
			$atts['items']          = $this->parse_repeater_items( $atts['children'] );
			$atts['total_price']    = $this->getPrice( $atts );

			return solvent_core_get_template_part( 'shortcodes/pricing-calculator', 'variations/' . $atts['layout'] . '/templates/' . $atts['layout'], '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-pricing-calculator';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['skin'] ) ? 'qodef-skin--' . $atts['skin'] : '';
			$holder_classes[] = ! empty( $atts['featured_calculator'] ) && 'yes' === $atts['featured_calculator'] ? 'qodef-status--featured' : 'qodef-status--regular';

			return implode( ' ', $holder_classes );
		}

		private function getPrice( $atts ) {

			$total_price = ! empty( $atts['price'] ) ? $atts['price'] : 0;

			if ( is_array( $atts['items'] ) && count( $atts['items'] ) > 0 ) {
				foreach ( $atts['items'] as $item ) {
					if ( 'yes' === $item['item_active'] ) {
						$total_price += (float) $item['item_price'];
					}
				}
			}

			return $total_price;
		}

		private function generate_image_params( $atts ) {
			$image = array();

			if ( ! empty( $atts['image'] ) ) {
				$id = $atts['image'];

				if ( is_array( wp_get_attachment_image_src( $id ) ) ) {
					$image['image_id'] = intval( $id );
					$image_original    = wp_get_attachment_image_src( $id, 'full' );
					$image['url']      = $image_original[0];
					$image['alt']      = get_post_meta( $id, '_wp_attachment_image_alt', true );

					$image_size = trim( $atts['image_size'] );
					preg_match_all( '/\d+/', $image_size, $matches ); /* check if numeral width and height are entered */
					if ( in_array( $image_size, array( 'thumbnail', 'thumb', 'medium', 'large', 'full' ), true ) ) {
						$image['image_size'] = $image_size;
					} elseif ( ! empty( $matches[0] ) ) {
						$image['image_size'] = array(
							$matches[0][0],
							$matches[0][1],
						);
					} else {
						$image['image_size'] = 'full';
					}
				}
			}

			return $image;
		}

		private function generate_button_params( $atts ) {
			$params = $this->populate_imported_shortcode_atts(
				array(
					'shortcode_base' => 'solvent_core_button',
					'exclude'        => array( 'custom_class' ),
					'atts'           => $atts,
				)
			);

			return $params;
		}
	}
}
