<?php

if ( ! function_exists( 'solvent_core_add_pricing_table_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function solvent_core_add_pricing_table_shortcode( $shortcodes ) {
		$shortcodes[] = 'SolventCore_Pricing_Table_Shortcode';

		return $shortcodes;
	}

	add_filter( 'solvent_core_filter_register_shortcodes', 'solvent_core_add_pricing_table_shortcode' );
}

if ( class_exists( 'SolventCore_Shortcode' ) ) {
	class SolventCore_Pricing_Table_Shortcode extends SolventCore_Shortcode {

		public function __construct() {
			$this->set_layouts( apply_filters( 'solvent_core_filter_pricing_table_layouts', array() ) );
			$this->set_extra_options( apply_filters( 'solvent_core_filter_pricing_table_extra_options', array() ) );

			parent::__construct();
		}

		public function map_shortcode() {
			$this->set_shortcode_path( SOLVENT_CORE_SHORTCODES_URL_PATH . '/pricing-table' );
			$this->set_base( 'solvent_core_pricing_table' );
			$this->set_name( esc_html__( 'Pricing Table', 'solvent-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds pricing table element', 'solvent-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'solvent-core' ),
				)
			);

			$options_map = solvent_core_get_variations_options_map( $this->get_layouts() );

			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'solvent-core' ),
					'options'       => $this->get_layouts(),
					'default_value' => 'standard',
					'visibility'    => array( 'map_for_page_builder' => $options_map['visibility'] ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'skin',
					'title'      => esc_html__( 'Skin', 'solvent-core' ),
					'options'    => solvent_core_get_select_type_options_pool( 'shortcode_skin' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'featured_table',
					'title'         => esc_html__( 'Featured Table', 'solvent-core' ),
					'options'       => solvent_core_get_select_type_options_pool( 'no_yes' ),
					'default_value' => 'no',
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'title',
					'title'         => esc_html__( 'Title', 'solvent-core' ),
					'default_value' => esc_html__( 'Title', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'price',
					'title'         => esc_html__( 'Price', 'solvent-core' ),
					'default_value' => esc_html__( '2500', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'currency',
					'title'         => esc_html__( 'Currency', 'solvent-core' ),
					'default_value' => esc_html__( '$', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'period',
					'title'         => esc_html__( 'Period', 'solvent-core' ),
					'default_value' => esc_html__( 'Annually', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'repeater',
					'name'       => 'children',
					'title'      => esc_html__( 'Feature Elements', 'solvent-core' ),
					'items'      => array(
						array(
							'field_type'    => 'text',
							'name'          => 'feature_text',
							'title'         => esc_html__( 'Feature Text', 'solvent-core' ),
							'default_value' => '',
						),
					),
				)
			);
			$this->import_shortcode_options(
				array(
					'shortcode_base'    => 'solvent_core_button',
					'exclude'           => array( 'custom_class' ),
					'additional_params' => array(
						'nested_group' => esc_html__( 'Button', 'solvent-core' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'download_title',
					'title'      => esc_html__( 'Download Title', 'solvent-core' ),
					'group'      => esc_html__( 'Download', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'download_text',
					'title'      => esc_html__( 'Download Text', 'solvent-core' ),
					'group'      => esc_html__( 'Download', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'download_link',
					'title'      => esc_html__( 'Download Link', 'solvent-core' ),
					'group'      => esc_html__( 'Download', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'download_target',
					'title'         => esc_html__( 'Download Target', 'solvent-core' ),
					'options'       => solvent_core_get_select_type_options_pool( 'link_target' ),
					'group'         => esc_html__( 'Download', 'solvent-core' ),
					'default_value' => '_self',
					'dependency'    => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'commission_title',
					'title'      => esc_html__( 'Commission Title', 'solvent-core' ),
					'group'      => esc_html__( 'Commission', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'commission_text',
					'title'      => esc_html__( 'Commission Text', 'solvent-core' ),
					'group'      => esc_html__( 'Commission', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'commission_price',
					'title'      => esc_html__( 'Commission Price', 'solvent-core' ),
					'group'      => esc_html__( 'Commission', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'standard',
								'default_value' => 'standard',
							),
						),
					),
				)
			);
			$this->map_extra_options();
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['button_params']  = $this->generate_button_params( $atts );
			$atts['items']          = $this->parse_repeater_items( $atts['children'] );

			return solvent_core_get_template_part( 'shortcodes/pricing-table', 'variations/' . $atts['layout'] . '/templates/' . $atts['layout'], '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-pricing-table';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['skin'] ) ? 'qodef-skin--' . $atts['skin'] : '';
			$holder_classes[] = ! empty( $atts['featured_table'] ) && 'yes' === $atts['featured_table'] ? 'qodef-status--featured' : 'qodef-status--regular';

			return implode( ' ', $holder_classes );
		}

		private function generate_button_params( $atts ) {
			$params = $this->populate_imported_shortcode_atts(
				array(
					'shortcode_base' => 'solvent_core_button',
					'exclude'        => array( 'custom_class' ),
					'atts'           => $atts,
				)
			);

			return $params;
		}
	}
}
