<?php

if ( ! function_exists( 'solvent_core_add_progress_bar_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function solvent_core_add_progress_bar_shortcode( $shortcodes ) {
		$shortcodes[] = 'SolventCore_Progress_Bar_Shortcode';

		return $shortcodes;
	}

	add_filter( 'solvent_core_filter_register_shortcodes', 'solvent_core_add_progress_bar_shortcode' );
}

if ( class_exists( 'SolventCore_Shortcode' ) ) {
	class SolventCore_Progress_Bar_Shortcode extends SolventCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( SOLVENT_CORE_SHORTCODES_URL_PATH . '/progress-bar' );
			$this->set_base( 'solvent_core_progress_bar' );
			$this->set_name( esc_html__( 'Progress Bar', 'solvent-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays progress bar with provided parameters', 'solvent-core' ) );
			$this->set_scripts(
				array(
					'progress-bar-circle' => array(
						'registered' => false,
						'url'        => SOLVENT_CORE_INC_URL_PATH . '/shortcodes/progress-bar/assets/js/plugins/progressbar.min.js',
						'dependency' => array( 'jquery' ),
					),
					'progress-bar-line'   => array(
						'registered' => false,
						'url'        => SOLVENT_CORE_INC_URL_PATH . '/shortcodes/progress-bar/assets/js/plugins/jquery.lineProgressbar.js',
						'dependency' => array( 'jquery' ),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'layout',
					'title'         => esc_html__( 'Layout', 'solvent-core' ),
					'options'       => array(
						'circle'     => esc_html__( 'Circle', 'solvent-core' ),
						'horizontal' => esc_html__( 'Horizontal', 'solvent-core' ),
						'vertical'   => esc_html__( 'Vertical', 'solvent-core' ),
					),
					'default_value' => 'horizontal',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'percentage_type',
					'title'      => esc_html__( 'Percentage Type', 'solvent-core' ),
					'options'    => array(
						'fixed'    => esc_html__( 'Fixed', 'solvent-core' ),
						'floating' => esc_html__( 'Floating', 'solvent-core' ),
					),
					'dependency' => array(
						'show' => array(
							'layout' => array(
								'values'        => 'horizontal',
								'default_value' => 'circle',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'bar_size',
					'title'      => esc_html__( 'Bar Size', 'solvent-core' ),
					'group'      => esc_html__( 'Bar Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'active_line_color',
					'title'      => esc_html__( 'Active Line Color', 'solvent-core' ),
					'group'      => esc_html__( 'Line Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'active_line_width',
					'title'       => esc_html__( 'Active Line Width', 'solvent-core' ),
					'description' => esc_html__( 'Enter width for active line without unit. Default value is 5 (1 is equal 3.59px for circle and custom type)', 'solvent-core' ),
					'group'       => esc_html__( 'Line Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'inactive_line_color',
					'title'      => esc_html__( 'Inactive Color', 'solvent-core' ),
					'group'      => esc_html__( 'Line Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'inactive_line_width',
					'title'       => esc_html__( 'Inactive Line Width', 'solvent-core' ),
					'description' => esc_html__( 'Enter width for inactive line without unit. Default value is 5 (1 is equal 3.59px for circle and custom type)', 'solvent-core' ),
					'group'       => esc_html__( 'Line Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'enable_gradient_fill',
					'title'         => esc_html__( 'Enable Gradient Fill', 'solvent-core' ),
					'options'       => solvent_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'yes',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'gradient_color_start',
					'title'      => esc_html__( 'Gradient Color Start', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'enable_gradient_fill' => array(
								'values'        => 'yes',
								'default_value' => 'no',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'gradient_color_end',
					'title'      => esc_html__( 'Gradient Color End', 'solvent-core' ),
					'dependency' => array(
						'show' => array(
							'enable_gradient_fill' => array(
								'values'        => 'yes',
								'default_value' => 'no',
							),
						),
					),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'duration',
					'title'       => esc_html__( 'Animation Duration (ms)', 'solvent-core' ),
					'description' => esc_html__( 'Speed of progress animation in milliseconds. Default value is 1600.', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'number',
					'title'         => esc_html__( 'Percentage Number', 'solvent-core' ),
					'description'   => esc_html__( 'Enter percentage number for progress bar', 'solvent-core' ),
					'default_value' => '46',
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'number_color',
					'title'      => esc_html__( 'Number Color', 'solvent-core' ),
					'group'      => esc_html__( 'Number Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'title',
					'title'         => esc_html__( 'Title', 'solvent-core' ),
					'default_value' => esc_html__( 'Title Text', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'title_tag',
					'title'         => esc_html__( 'Title Tag', 'solvent-core' ),
					'options'       => solvent_core_get_select_type_options_pool( 'title_tag' ),
					'default_value' => 'h6',
					'group'         => esc_html__( 'Title Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'color',
					'name'       => 'title_color',
					'title'      => esc_html__( 'Title Color', 'solvent-core' ),
					'group'      => esc_html__( 'Title Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'title_margin',
					'title'       => esc_html__( 'Title Margin', 'solvent-core' ),
					'description' => esc_html__( 'If you selected a progress bar layout other than line this option corresponds to the margin top; in the event line layout type is selected, the option corresponds to the margin bottom.', 'solvent-core' ),
					'group'       => esc_html__( 'Title Style', 'solvent-core' ),
				)
			);
		}

		public function load_assets() {
			$atts = $this->get_atts();

			wp_enqueue_script( 'progress-bar-circle' );
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'solvent_core_progress_bar', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['holder_styles']  = $this->get_holder_styles( $atts );
			$atts['title_styles']   = $this->get_title_styles( $atts );
			$atts['number_style']   = $this->get_number_styles( $atts );
			$atts['bar_styles']     = $this->get_bar_styles( $atts );
			$atts['data_attrs']     = $this->get_data_attrs( $atts );

			return solvent_core_get_template_part( 'shortcodes/progress-bar', 'templates/progress-bar', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-progress-bar';
			$holder_classes[] = ! empty( $atts['layout'] ) ? 'qodef-layout--' . $atts['layout'] : '';
			$holder_classes[] = ! empty( $atts['enable_gradient_fill'] ) && 'yes' === $atts['enable_gradient_fill'] ? 'qodef--gradient' : '';

			if ( ! empty( $atts['percentage_type'] ) ) {
				$holder_classes[] = 'qodef-percentage--' . $atts['percentage_type'];
			}

			return implode( ' ', $holder_classes );
		}

		private function get_holder_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['inactive_line_width'] ) ) {
				if ( qode_framework_string_ends_with_space_units( $atts['inactive_line_width'] ) ) {
					$styles[] = '--qode-pb-inactive-line-width: ' . $atts['inactive_line_width'];
				} else {
					$styles[] = '--qode-pb-inactive-line-width: ' . intval( $atts['inactive_line_width'] ) . 'px';
				}
			}

			if ( ! empty( $atts['active_line_color'] ) ) {
				$styles[] = '--qode-pb-active-line-color: ' . $atts['active_line_color'];
			}

			if ( ! empty( $atts['inactive_line_color'] ) ) {
				$styles[] = '--qode-pb-inactive-line-color: ' . $atts['inactive_line_color'];
			}

			if ( ! empty( $atts['gradient_color_start'] ) ) {
				$styles[] = '--qode-pb-gradient-start-color: ' . $atts['gradient_color_start'];
			}

			if ( ! empty( $atts['gradient_color_end'] ) ) {
				$styles[] = '--qode-pb-gradient-end-color: ' . $atts['gradient_color_end'];
			}

			return $styles;
		}

		private function get_data_attrs( $atts ) {
			$data = array();

			if ( ! empty( $atts['layout'] ) ) {
				$data['data-layout'] = $atts['layout'];
			}

			$data['data-bar-size'] = ! empty( $atts['bar_size'] ) ? $atts['bar_size'] : '224';

			$data['data-active-line-color'] = ! empty( $atts['active_line_color'] ) ? $atts['active_line_color'] : '#08132E';
			$data['data-active-line-width'] = ! empty( $atts['active_line_width'] ) ? floatval( $atts['active_line_width'] ) : 5;

			$data['data-inactive-line-color'] = ! empty( $atts['inactive_line_color'] ) ? $atts['inactive_line_color'] : '#D4E1E6';
			$data['data-inactive-line-width'] = ! empty( $atts['inactive_line_width'] ) ? floatval( $atts['inactive_line_width'] ) : 5;

			$data['data-duration'] = ! empty( $atts['duration'] ) ? intval( $atts['duration'] ) : '';
			$data['data-number']   = ! empty( $atts['number'] ) ? $atts['number'] : '0.00';

			$data['data-percentage-type'] = $atts['percentage_type'];
			$data['data-gradient-fill']   = $atts['enable_gradient_fill'];
			$data['data-rand-id']         = rand();

			$data['data-gradient-start'] = ! empty( $atts['gradient_color_start'] ) ? $atts['gradient_color_start'] : 'var(--qode-gradient-two-color)';
			$data['data-gradient-end']   = ! empty( $atts['gradient_color_end'] ) ? $atts['gradient_color_end'] : 'var(--qode-gradient-one-color)';

			$data['data-text-color'] = ! empty( $atts['number_color'] ) ? $atts['number_color'] : '#08132E';

			return $data;
		}

		private function get_bar_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['bar_size'] ) {
				if ( qode_framework_string_ends_with_space_units( $atts['bar_size'] ) ) {
					$styles[] = 'width: ' . $atts['bar_size'];
				} else {
					$styles[] = 'width: ' . intval( $atts['bar_size'] ) . 'px';
				}
			}

			return $styles;
		}

		private function get_title_styles( $atts ) {
			$styles = array();

			if ( '' !== $atts['title_margin'] ) {
				if ( 'horizontal' === $atts['layout'] ) {
					if ( qode_framework_string_ends_with_space_units( $atts['title_margin'] ) ) {
						$styles[] = 'margin-bottom: ' . $atts['title_margin'];
					} else {
						$styles[] = 'margin-bottom: ' . intval( $atts['title_margin'] ) . 'px';
					}
				} else {
					if ( qode_framework_string_ends_with_space_units( $atts['title_margin'] ) ) {
						$styles[] = 'margin-top: ' . $atts['title_margin'];
					} else {
						$styles[] = 'margin-top: ' . intval( $atts['title_margin'] ) . 'px';
					}
				}
			}

			if ( ! empty( $atts['title_color'] ) ) {
				$styles[] = 'color: ' . $atts['title_color'];
			}

			return $styles;
		}

		private function get_number_styles( $atts ) {
			$styles = array();

			if ( ! empty( $atts['number_color'] ) ) {
				$styles[] = 'color: ' . $atts['number_color'];
			}

			return $styles;
		}
	}
}
