<?php

if ( ! function_exists( 'solvent_core_add_scroll_indicator_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function solvent_core_add_scroll_indicator_shortcode( $shortcodes ) {
		$shortcodes[] = 'SolventCore_Scroll_Indicator_Shortcode';

		return $shortcodes;
	}

	add_filter( 'solvent_core_filter_register_shortcodes', 'solvent_core_add_scroll_indicator_shortcode' );
}

if ( class_exists( 'SolventCore_Shortcode' ) ) {
	class SolventCore_Scroll_Indicator_Shortcode extends SolventCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( SOLVENT_CORE_SHORTCODES_URL_PATH . '/scroll-indicator' );
			$this->set_base( 'solvent_core_scroll_indicator' );
			$this->set_name( esc_html__( 'Scroll Indicator', 'solvent-core' ) );
			$this->set_description( esc_html__( 'Shortcode that displays scroll indicator with provided parameters', 'solvent-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'custom_class',
					'title'      => esc_html__( 'Custom Class', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'text',
					'name'          => 'text',
					'title'         => esc_html__( 'Text', 'solvent-core' ),
					'default_value' => esc_html__( 'Scroll', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'skin',
					'title'         => esc_html__( 'Skin', 'solvent-core' ),
					'default_value' => '',
					'options'       => solvent_core_get_select_type_options_pool( 'shortcode_skin' ),
				)
			);
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );

			return solvent_core_get_template_part( 'shortcodes/scroll-indicator', 'templates/scroll-indicator', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-scroll-indicator';
			$holder_classes[] = ! empty( $atts['skin'] ) ? 'qodef-skin--' . $atts['skin'] : '';

			return implode( ' ', $holder_classes );
		}
	}
}
