<?php

if ( ! function_exists( 'solvent_core_add_services_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function solvent_core_add_services_shortcode( $shortcodes ) {
		$shortcodes[] = 'SolventCore_Services_Shortcode';

		return $shortcodes;
	}

	add_filter( 'solvent_core_filter_register_shortcodes', 'solvent_core_add_services_shortcode' );
}

if ( class_exists( 'SolventCore_List_Shortcode' ) ) {
	class SolventCore_Services_Shortcode extends SolventCore_List_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( SOLVENT_CORE_SHORTCODES_URL_PATH . '/services' );
			$this->set_base( 'solvent_core_services' );
			$this->set_name( esc_html__( 'Services', 'solvent-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds services element', 'solvent-core' ) );
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'static_title',
					'title'      => esc_html__( 'Static Title', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'line_break_positions',
					'title'       => esc_html__( 'Positions of Line Break', 'solvent-core' ),
					'description' => esc_html__( 'Enter the positions of the words after which you would like to create a line break. Separate the positions with commas (e.g. if you would like the first, third, and fourth word to have a line break, you would enter "1,3,4")', 'solvent-core' ),
					'group'       => esc_html__( 'Static Title Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'disable_title_break_words',
					'title'         => esc_html__( 'Disable Title Line Break', 'solvent-core' ),
					'description'   => esc_html__( 'Enabling this option will disable title line breaks for screen size 1200 and lower', 'solvent-core' ),
					'options'       => solvent_core_get_select_type_options_pool( 'no_yes', false ),
					'default_value' => 'no',
					'group'         => esc_html__( 'Static Title Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'highlight_position',
					'title'       => esc_html__( 'Highlight Text Position', 'solvent-core' ),
					'description' => esc_html__( 'Enter the positions of the words you would like to display as "highlight" text. Separate start and end positions with commas (e.g. if you would like to wrap from fifth to ninth words, you would enter "5,9") or if you want to highlight whole text fill -1', 'solvent-core' ),
					'group'       => esc_html__( 'Static Title Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type'    => 'select',
					'name'          => 'static_title_tag',
					'title'         => esc_html__( 'Static Title Tag', 'solvent-core' ),
					'options'       => solvent_core_get_select_type_options_pool( 'title_tag', false ),
					'default_value' => 'h2',
					'group'         => esc_html__( 'Static Title Style', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'text',
					'name'       => 'static_subtitle',
					'title'      => esc_html__( 'Static Subtitle', 'solvent-core' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'enable_arrow',
					'title'      => esc_html__( 'Enable Arrow', 'solvent-core' ),
					'options'    => solvent_core_get_select_type_options_pool( 'yes_no', false ),
					'default_value' => 'yes'
				)
			);
			$this->set_option(
				array(
					'field_type' => 'repeater',
					'name'       => 'children',
					'title'      => esc_html__( 'Child elements', 'solvent-core' ),
					'items'      => array(
						array(
							'field_type' => 'image',
							'name'       => 'item_image',
							'title'      => esc_html__( 'Image', 'solvent-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'item_title',
							'title'      => esc_html__( 'Title', 'solvent-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'item_text',
							'title'      => esc_html__( 'Text', 'solvent-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'link',
							'title'      => esc_html__( 'Link', 'solvent-core' ),
						),
						array(
							'field_type'    => 'select',
							'name'          => 'target',
							'title'         => esc_html__( 'Link Target', 'solvent-core' ),
							'options'       => solvent_core_get_select_type_options_pool( 'link_target' ),
							'default_value' => '_self',
						),
					),
				)
			);

			$this->map_list_options(
				array(
					'exclude_behavior'      => array( 'justified-gallery', 'masonry' ),
					'exclude_option'        => array( 'images_proportion' ),
					'group'                 => esc_html__( 'Gallery Settings', 'solvent-core' ),
					'include_slider_option' => array(
						'slider_direction',
						'slider_hidden_slides',
						'slider_mousewheel_navigation',
					),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'partial_columns',
					'title'      => esc_html__( 'Enable Partial Columns', 'solvent-core' ),
					'options'    => solvent_core_get_select_type_options_pool( 'no_yes', false ),
				)
			);

			$this->set_option(
				array(
					'field_type'  => 'text',
					'name'        => 'partial_columns_value',
					'title'       => esc_html__( 'Partial Columns Value', 'solvent-core' ),
					'description' => esc_html__( 'Value can be between 0 and 1', 'solvent-core' ),
					'dependency'  => array(
						'show' => array(
							'partial_columns' => array(
								'values'        => 'yes',
								'default_value' => 'no',
							),
						),
					),
				)
			);

			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'disable_partial_columns_under',
					'title'      => esc_html__( 'Disable Partial Columns Under', 'solvent-core' ),
					'options'    => array(
						''     => esc_html__( 'Never', 'solvent-core' ),
						'1200' => esc_html__( '1200', 'solvent-core' ),
						'1024' => esc_html__( '1024', 'solvent-core' ),
						'880'  => esc_html__( '880', 'solvent-core' ),
						'680'  => esc_html__( '680', 'solvent-core' ),
					),
					'dependency' => array(
						'show' => array(
							'partial_columns' => array(
								'values'        => 'yes',
								'default_value' => 'no',
							),
						),
					),
				)
			);
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['unique'] = rand( 0, 1000 );

			$atts['static_title']   = $this->get_modified_title( $atts );
			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['outer_classes']  = $this->get_outer_classes( $atts );
			$atts['holder_styles']  = $this->get_holder_styles( $atts );
			$atts['item_classes']   = $this->get_item_classes( $atts );
			$atts['slider_attr']    = $this->get_slider_data( $atts, array( 'unique' => $atts['unique'] ) );
			$atts['items']          = $this->parse_repeater_items( $atts['children'] );

			return solvent_core_get_template_part( 'shortcodes/services', 'templates/services', $atts['behavior'], $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-services';
			$holder_classes[] = 'qodef-swiper-container';
			$holder_classes[] = 'no' !== $atts['enable_arrow'] ? 'qodef-arrow--enabled' : 'qodef-arrow--disabled';

			$list_classes   = $this->get_list_classes( $atts );
			$holder_classes = array_merge( $holder_classes, $list_classes );

			return implode( ' ', $holder_classes );
		}

		private function get_outer_classes( $atts ) {
			$holder_classes[] = 'qodef-services-outer';

			$holder_classes[] = 'yes' === $atts['disable_title_break_words'] ? 'qodef-title-break--disabled' : '';

			return implode( ' ', $holder_classes );
		}

		private function get_holder_styles( $atts ) {
			$holder_styles = array();

			$list_styles   = $this->get_list_styles( $atts );
			$holder_styles = array_merge( $holder_styles, $list_styles );

			return $holder_styles;
		}

		public function get_item_classes( $atts ) {
			$item_classes = $this->init_item_classes();

			$item_classes[] = 'qodef-e';
			$item_classes[] = 'swiper-slide';

			$list_item_classes = $this->get_list_item_classes( $atts );

			$item_classes = array_merge( $item_classes, $list_item_classes );

			return implode( ' ', $item_classes );
		}

		private function get_modified_title( $atts ) {
			$title = $atts['static_title'];

			if ( ! empty( $title ) && ! empty( $atts['highlight_position'] ) ) {

				$highlight_position = $atts['highlight_position'];
				$text_prefix        = '<span class="qodef-highlight-text">';
				$text_suffix        = '</span>';
				$text_break         = '<br>';

				if ( '-1' === $highlight_position ) {

					if ( ! empty( $atts['line_break_positions'] ) ) {
						$split_title          = explode( ' ', $title );
						$line_break_positions = explode( ',', str_replace( ' ', '', $atts['line_break_positions'] ) );

						foreach ( $line_break_positions as $position ) {
							$position = intval( $position );
							if ( isset( $split_title[ $position - 1 ] ) && ! empty( $split_title[ $position - 1 ] ) ) {
								$split_title[ $position - 1 ] = $split_title[ $position - 1 ] . $text_break;
							}
						}

						$title = implode( ' ', $split_title );
					}

					$title = $text_prefix . $title . $text_suffix;
				} else {
					$split_text           = explode( ' ', $title );
					$highlight_position   = explode( ',', str_replace( ' ', '', $atts['highlight_position'] ) );
					$line_break_positions = explode( ',', str_replace( ' ', '', $atts['line_break_positions'] ) );
					$positions            = array_filter(
						array(
							'start' => isset( $highlight_position[0] ) ? $highlight_position[0] : '',
							'end'   => isset( $highlight_position[1] ) ? $highlight_position[1] : '',
						)
					);
					$positions            = array_merge( $positions, $line_break_positions );
					asort( $positions );

					if ( ! empty( $positions ) ) {
						foreach ( $positions as $key => $value ) {
							$text_prefix_html = 'start' === $key ? $text_prefix : '';
							$text_suffix_html = 'end' === $key ? $text_suffix : '';
							$text_break_html  = in_array( $value, $line_break_positions, true ) && 'start' !== $key && 'end' !== $key ? $text_break : '';

							if ( isset( $split_text[ intval( $value ) - 1 ] ) && ! empty( $split_text[ intval( $value ) - 1 ] ) ) {
								$split_text[ $value - 1 ] = $text_prefix_html . $split_text[ $value - 1 ] . $text_suffix_html . $text_break_html;
							}
						}

						$title = implode( ' ', $split_text );
					}
				}
			} else {
				if ( ! empty( $atts['line_break_positions'] ) ) {
					$split_title          = explode( ' ', $title );
					$line_break_positions = explode( ',', str_replace( ' ', '', $atts['line_break_positions'] ) );

					foreach ( $line_break_positions as $position ) {
						$position = intval( $position );
						if ( isset( $split_title[ $position - 1 ] ) && ! empty( $split_title[ $position - 1 ] ) ) {
							$split_title[ $position - 1 ] = $split_title[ $position - 1 ] . '<br />';
						}
					}

					$title = implode( ' ', $split_title );
				}
			}

			return $title;
		}
	}
}
