<?php

if ( ! function_exists( 'solvent_core_add_showcase_shortcode' ) ) {
	/**
	 * Function that add shortcode into shortcodes list for registration
	 *
	 * @param array $shortcodes
	 *
	 * @return array
	 */
	function solvent_core_add_showcase_shortcode( $shortcodes ) {
		$shortcodes[] = 'SolventCore_Showcase_Shortcode';

		return $shortcodes;
	}

	add_filter( 'solvent_core_filter_register_shortcodes', 'solvent_core_add_showcase_shortcode' );
}

if ( class_exists( 'SolventCore_Shortcode' ) ) {
	class SolventCore_Showcase_Shortcode extends SolventCore_Shortcode {

		public function map_shortcode() {
			$this->set_shortcode_path( SOLVENT_CORE_SHORTCODES_URL_PATH . '/showcase' );
			$this->set_base( 'solvent_core_showcase' );
			$this->set_name( esc_html__( 'Showcase', 'solvent-core' ) );
			$this->set_description( esc_html__( 'Shortcode that adds showcase element', 'solvent-core' ) );
			$this->set_option(
				array(
					'field_type' => 'select',
					'name'       => 'skin',
					'title'      => esc_html__( 'Skin', 'solvent-core' ),
					'options'    => solvent_core_get_select_type_options_pool( 'shortcode_skin' ),
				)
			);
			$this->set_option(
				array(
					'field_type' => 'repeater',
					'name'       => 'children',
					'title'      => esc_html__( 'Child elements', 'solvent-core' ),
					'items'      => array(
						array(
							'field_type' => 'text',
							'name'       => 'item_subtitle',
							'title'      => esc_html__( 'Subtitle', 'solvent-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'item_title',
							'title'      => esc_html__( 'Title', 'solvent-core' ),
						),
						array(
							'field_type' => 'textarea',
							'name'       => 'item_text',
							'title'      => esc_html__( 'Text', 'solvent-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'item_button_text',
							'title'      => esc_html__( 'Button Text', 'solvent-core' ),
						),
						array(
							'field_type' => 'text',
							'name'       => 'item_button_link',
							'title'      => esc_html__( 'Button Link', 'solvent-core' ),
						),
						array(
							'field_type'    => 'select',
							'name'          => 'item_button_target',
							'title'         => esc_html__( 'Button Target', 'solvent-core' ),
							'options'       => solvent_core_get_select_type_options_pool( 'link_target' ),
							'default_value' => '_self',
						)
					),
				)
			);
		}

		public static function call_shortcode( $params ) {
			$html = qode_framework_call_shortcode( 'solvent_core_showcase', $params );
			$html = str_replace( "\n", '', $html );

			return $html;
		}

		public function render( $options, $content = null ) {
			parent::render( $options );
			$atts = $this->get_atts();

			$atts['holder_classes'] = $this->get_holder_classes( $atts );
			$atts['item_classes']   = $this->get_item_classes( $atts );
			$atts['items']          = $this->parse_repeater_items( $atts['children'] );

			return solvent_core_get_template_part( 'shortcodes/showcase', 'templates/showcase', '', $atts );
		}

		private function get_holder_classes( $atts ) {
			$holder_classes = $this->init_holder_classes();

			$holder_classes[] = 'qodef-showcase qodef--autoplay';
			$holder_classes[] = ! empty( $atts['skin'] ) ? 'qodef-skin--' . $atts['skin'] : '';

			return implode( ' ', $holder_classes );
		}

		public function get_item_classes( $atts ) {
			$item_classes[] = 'qodef-e-item';

			return implode( ' ', $item_classes );
		}
	}
}
